==> slurm_rest_client-0.1.3-py3-none-any.whl: slurm_rest_client/models/v0040_step_statistics_energy.py <==
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.v0040_step_statistics_energy_consumed import V0040StepStatisticsEnergyConsumed


T = TypeVar("T", bound="V0040StepStatisticsEnergy")


@_attrs_define
class V0040StepStatisticsEnergy:
    """
    Attributes:
        consumed (Union[Unset, V0040StepStatisticsEnergyConsumed]):
    """

    consumed: Union[Unset, "V0040StepStatisticsEnergyConsumed"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        consumed: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.consumed, Unset):
            consumed = self.consumed.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if consumed is not UNSET:
            field_dict["consumed"] = consumed

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.v0040_step_statistics_energy_consumed import V0040StepStatisticsEnergyConsumed

        d = dict(src_dict)
        _consumed = d.pop("consumed", UNSET)
        consumed: Union[Unset, V0040StepStatisticsEnergyConsumed]
        if isinstance(_consumed, Unset):
            consumed = UNSET
        else:
            consumed = V0040StepStatisticsEnergyConsumed.from_dict(_consumed)

        v0040_step_statistics_energy = cls(
            consumed=consumed,
        )

        v0040_step_statistics_energy.additional_properties = d
        return v0040_step_statistics_energy

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> slurm_rest_client-0.1.4-py3-none-any.whl: slurm_rest_client/models/v0040_step_statistics_energy.py <==
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="V0040StepStatisticsEnergy")


@_attrs_define
class V0040StepStatisticsEnergy:
    """
    Attributes:
        consumed (Union[Unset, int]):
    """

    consumed: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        consumed = self.consumed

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if consumed is not UNSET:
            field_dict["consumed"] = consumed

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        consumed = d.pop("consumed", UNSET)

        v0040_step_statistics_energy = cls(
            consumed=consumed,
        )

        v0040_step_statistics_energy.additional_properties = d
        return v0040_step_statistics_energy

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
